@@ -20,8 +20,4 @@ class papyrusProcessor:
         for a_step in pipeline:
             request_info = a_step(request_info)
 
-        return request_info
-
-
-processor = papyrusProcessor('/Users/palashshah/desktop/papyrus/papyrus/test.json', 'housing.csv')
-print(processor.run())
\ No newline at end of file
+        return request_info
\ No newline at end of file
